@@ -30,6 +30,7 @@ c      kDebye:  Debye function
 c      kBern:   Bernuoulli number
 c      kalpha:  see if string starts with a-z or A-Z
 c      kxplellip: crossing point of a line with an ellipse
+c      kgsub:  substitute string 
 c      ****************************
       logical function kalpha(string)
 c
@@ -2118,3 +2119,59 @@ c
          endif
       endif
       end
+c      character*80 si, so  
+c      character*4  t, r
+c      read(*,'(a)') r
+c      read(*,'(a)') t
+c      read(*,'(a)') si
+c      call kgsub(r, t, si, so)
+c      write(*,*) so
+c      end
+c*****************************************
+      subroutine kgsub(r, t, si, so)
+      implicit none
+c        replace stgring r in si by t and put so
+c     
+      character*(*)  r  ! input.
+      character*(*)  t  ! input.
+      character*(*)  si ! input.
+      character*(*)  so ! output.
+
+      integer klena, ir, it, isi, iso, i, j
+
+      ir = klena(r)
+      it = klena(t)
+      isi = klena(si)
+      iso = len(so)
+      
+      i = 1
+      j = 0
+      so = ' '
+      do while ( i .le. isi )
+         if(i+ir-1 .le. isi) then
+            if( si(i:i+ir-1) .eq. r(1:ir)) then
+               j = j + 1
+               so(j:j+it-1) = t(1:it)
+               j = j + it -1
+               i = i + ir
+            else
+               j = j + 1
+               so(j:j+it-1) = si(i:i)
+               i = i + 1
+            endif
+         else
+            j = j + 1 
+            so(j:j+it-1) = si(i:i)
+            i = i +1
+         endif
+         if(j .gt. iso) then
+            write(0,*)
+     *      ' output string length is too short: kgsub'
+            stop 9999
+         endif
+      enddo
+      end
+
+
+      
+      
